{% extends "!layout.html" %}

  {% block menu %}

  <div class="rst-versions" data-toggle="rst-versions" role="note" aria-label="versions">
      <span class="rst-current-version" data-toggle="rst-current-version">
        <span class="fa fa-book"> Versions</span>
        v: {{ current_version }}
        <span class="fa fa-caret-down"></span>
      </span>
      <div class="rst-other-versions">
        <dl>
          <dt>{{ _('Versions') }}</dt>
          {% for slug, url in versions %}
            <dd><a href="{{ url }}">{{ slug }}</a></dd>
          {% endfor %}
        </dl>
      </div>
    </div>

    {{ super() }}

  {% endblock %}

  {% block versions %}{% endblock %}
